/*************************************************************************
* COPYRIGHT (C) 1999 - 2002  EDF R&D
* THIS LIBRARY IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
* IT UNDER THE TERMS OF THE GNU LESSER GENERAL PUBLIC LICENSE 
* AS PUBLISHED BY THE FREE SOFTWARE FOUNDATION; 
* EITHER VERSION 2.1 OF THE LICENSE, OR (AT YOUR OPTION) ANY LATER VERSION.
*  
* THIS LIBRARY IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
* WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
* MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
* LESSER GENERAL PUBLIC LICENSE FOR MORE DETAILS.
*
* YOU SHOULD HAVE RECEIVED A COPY OF THE GNU LESSER GENERAL PUBLIC LICENSE
* ALONG WITH THIS LIBRARY; IF NOT, WRITE TO THE FREE SOFTWARE FOUNDATION,
* INC., 59 TEMPLE PLACE, SUITE 330, BOSTON, MA 02111-1307 USA
*
*************************************************************************/


/******************************************************************************
 * - Nom du fichier : test11.c
 *
 * - Description : lecture de champs de resultats MED 
 *
 *****************************************************************************/

#include <med.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#define USER_INTERLACE MED_FULL_INTERLACE

/******************************************************************************
 * Description :
 *    - ouverture du fichier
 *    - lecture des champs d'un fichier MED
 *    - fermeture du fichier
 *****************************************************************************/

int main (int argc, char **argv)
{
  med_err ret;
  med_idt fid;
  char maa[MED_TAILLE_NOM+1];
  med_int mdim,numdt,numo,nbpdtnor;
  char *comp, *unit;
  char nomcha  [MED_TAILLE_NOM+1];
  char pflname [MED_TAILLE_NOM+1];
  char maa_ass [MED_TAILLE_NOM+1];
  char dt_unit [MED_TAILLE_PNOM+1]="C      ";
  med_int ncomp;
  med_float *valr,dt;
  med_int *vale;
  med_type_champ typcha;
  int i,j,k,l;
  med_int ncha,npro,pflsize,*pflval,ngauss;
  med_int nval;
  med_geometrie_element typmai[MED_NBR_GEOMETRIE_MAILLE] = {MED_POINT1,MED_SEG2, 
							    MED_SEG3,MED_TRIA3,
							    MED_TRIA6,MED_QUAD4,
							    MED_QUAD8,MED_TETRA4,
							    MED_TETRA10,MED_HEXA8,
							    MED_HEXA20,MED_PENTA6,
							    MED_PENTA15,MED_PYRA5,
							    MED_PYRA13};
  med_geometrie_element typfac[MED_NBR_GEOMETRIE_FACE] = {MED_TRIA3,MED_TRIA6,
							  MED_QUAD4,MED_QUAD8};
  med_geometrie_element typare[MED_NBR_GEOMETRIE_ARETE] = {MED_SEG2,MED_SEG3};  

  if (argc != 2)
    return -1;

  /* ouverture du fichier */
  if ((fid = MEDouvrir(argv[1],MED_LECT)) < 0)
    ret = -1;
  else
    ret = 0;
  printf("%d\n",ret);
  
  /* infos sur le premier maillage */
  if (ret == 0)
    ret = MEDmaaInfo(fid,1,maa,&mdim);
  if (ret == 0)
    printf("Maillage de nom %s et de dimension %d \n",maa,mdim);
  printf("%d\n",ret);

  /* combien de champs dans le fichier */
  if (ret == 0)
    if ((ncha = MEDnChamp(fid,0)) < 0)
      ret = -1;
  if (ret == 0)
    printf("Nombre de champs : %d \n",ncha);
  printf("%d\n",ret);
  
  /* lecture de tous les champs  */
  if (ret == 0)
    for (i =0;i<ncha;i++)
      {
	printf("\nChamp numero : %d \n",i+1);

	/* combien de composantes */
	if (ret == 0)
	  if ((ncomp = MEDnChamp(fid,i+1)) < 0)
	    ret = -1;
	printf("%d\n",ret);
        
	/* allocation memoire de comp et unit*/
        if (ret == 0) {
	  comp = (char*) malloc(ncomp*MED_TAILLE_PNOM+1);
	  unit = (char*) malloc(ncomp*MED_TAILLE_PNOM+1);
	  
	  /* infos sur les champs */
          ret = MEDchampInfo(fid,i+1,nomcha,&typcha,comp,unit,ncomp);
	  
	  printf("Nom du champ : %s de type %d\n",nomcha,typcha);
	  printf("Nom des composantes : %s\n",comp);
	  printf("Unites des composantes : %s \n",unit);
	  
	  free(comp);
	  free(unit);
	}

	if (ret == 0)
	  {	    

            /* Combien de (PDT,NOR) a lire */
            /* Sur les noeuds */
	    nbpdtnor = MEDnPasdetemps(fid,nomcha,MED_NOEUD,0);
            
	    for (j=0;j<nbpdtnor;j++) {
              
              /* Ajouter les informations sur le profil ?? dans MEDpasdetempsInfo */
	      ret = MEDpasdetempsInfo(fid,nomcha,MED_NOEUD,0,
				      j+1, maa_ass, &ngauss, &numdt,  dt_unit, &dt, &numo);
              
              printf("\n\tPas de Temps n %4i (%f), Nd'ordre %4i, avec %i pts de gauss\n",numdt,dt,numo,ngauss);
    
              if ((nval = MEDnVal(fid,nomcha,MED_NOEUD,0,numdt,numo)) < 0)  /*prend en compte le nbre de pt de gauss*/
		ret = -1;
	      
	      printf("\t- Il y a %d valeurs (%s) sur les noeuds associs au maillage %s\n",nval,dt_unit,maa_ass);
	
	      if (nval > 0) {
		if (typcha == MED_REEL64) {
		  valr = (med_float*) calloc(ncomp*nval,sizeof(med_float));       
		  ret = MEDchampLire(fid,maa,nomcha,(unsigned char*)valr,USER_INTERLACE,MED_ALL,
				     pflname,MED_NOEUD,0,numdt,numo);
		  for (l=0;l<nval*ncomp;l++) printf("\t- Valeurs : %f\n",*(valr+l));
		  free(valr);
		} else {
		  vale = (med_int*) calloc(ncomp*nval,sizeof(med_int));
		  ret = MEDchampLire(fid,maa,nomcha,(unsigned char*)vale,USER_INTERLACE,MED_ALL,
				     pflname,MED_NOEUD,0,numdt,numo);
		  for (k=0;k<nval*ncomp;k++) printf("\t- Valeurs : %i\n",*(vale+k));
		  free(vale);  
		}
		
		if (strcmp(pflname,MED_NOPFL) == 0 )
		  printf("\t- Profil : MED_NOPFL\n");
		else {
		  if ( (pflsize = MEDnValProfil(fid,pflname)) <0)
		    return -1;
		  else {
		    printf("\t- Profil : %s de taille %i\n",pflname,pflsize);
		    pflval = (med_int*) malloc(sizeof(med_int)*pflsize);
		    if ( (ret = MEDprofilLire(fid,pflval,pflname)) <0) return -1;
		    for (l=0;l<pflsize;l++) printf("\t%i\n",*(pflval+l));
		    free(pflval);
		  }
		}
		
	      } /*FIN : if (nval > 0) */
            }
	    
            for (k=0;k<MED_NBR_GEOMETRIE_MAILLE;k++)
              {
                /* Combien de (PDT,NPR) a lire */
                /* sur les mailles */
                nbpdtnor = MEDnPasdetemps(fid,nomcha,MED_MAILLE,typmai[k]); 
                if (nbpdtnor < 1 ) continue;

                for (j=0;j<nbpdtnor;j++) {
                  /* Ajouter les informations sur le profil ?? dans MEDpasdetempsInfo */
                  ret = MEDpasdetempsInfo(fid,nomcha,MED_MAILLE,typmai[k],
                                          j+1, maa_ass, &ngauss, &numdt,  dt_unit, &dt, &numo);
	
                  printf("\n\tPas de Temps n %4i (%f), Nd'ordre %4i, avec %i pts de gauss\n",numdt,dt,numo,ngauss);
                  if ((nval = MEDnVal(fid,nomcha,MED_MAILLE,typmai[k],numdt,numo)) < 0)  /*prend en compte le nbre de pt de gauss*/
                    ret = -1;
                  printf("\t- Il y a %d valeurs (%s) sur les mailles %d  associs au maillage %s\n",nval,dt_unit,typmai[k],maa_ass);
                    
                  if (nval > 0) {
		    
		    if (typcha == MED_REEL64) {
		      valr = (med_float*) calloc(ncomp*nval,sizeof(med_float));
		      ret = MEDchampLire(fid,maa,nomcha,(unsigned char*)valr,USER_INTERLACE,MED_ALL,
					 pflname,MED_MAILLE,typmai[k],numdt,numo);
		      for (l=0;l<nval*ncomp;l++) printf("\t- Valeurs : %f\n",*(valr+l));
		      free(valr);
		    } else {
		      /* vale = (med_int*) calloc(ncomp*nval,sizeof(med_int));*/
		      vale = (med_int*) calloc(ncomp*nval,sizeof(med_int));
		      ret = MEDchampLire(fid,maa,nomcha,(unsigned char*)vale,USER_INTERLACE,MED_ALL,
					 pflname,MED_MAILLE,typmai[k],numdt,numo);	
		      for (l=0;l<nval*ncomp;l++) printf("\t- Valeurs : %i\n",*(vale+l));
		      free(vale);
		    }
		    
		    if (strcmp(pflname,MED_NOPFL) == 0 )
		      printf("\t- Profil : MED_NOPFL\n");
		    else {
		      if ( (pflsize = MEDnValProfil(fid,pflname)) <0) 
			return -1;
		      else {
			printf("\t- Profil : %s de taille %i\n",pflname,pflsize);
			pflval = (med_int*) malloc(sizeof(med_int)*pflsize);
			if ( (ret = MEDprofilLire(fid,pflval,pflname)) <0) return -1;
			for (l=0;l<pflsize;l++) printf("\t%i\n",*(pflval+l));
			free(pflval);
		      }
		    }

		  } /* FIN: if (nval > 0) { */
                }    
              } /* fin for sur les mailles*/

	    
            /* sur les faces */
            for (k=0;k<MED_NBR_GEOMETRIE_FACE;k++) {
	      /* Combien de (PDT,NPR) a lire */
	      /* sur les faces */
	      nbpdtnor = MEDnPasdetemps(fid,nomcha,MED_FACE,typfac[k]);   
	      if (nbpdtnor < 1 ) continue;
	      
	      for (j=0;j<nbpdtnor;j++) {
		/* Ajouter les informations sur le profil ?? dans MEDpasdetempsInfo */
		ret = MEDpasdetempsInfo(fid,nomcha,MED_FACE,typfac[k],
					j+1, maa_ass, &ngauss, &numdt,  dt_unit, &dt, &numo);
		
		printf("\n\tPas de Temps n %4i (%f), Nd'ordre %4i, avec %i pts de gauss\n",numdt,dt,numo,ngauss);
		
		if ((nval = MEDnVal(fid,nomcha,MED_FACE,typfac[k],numdt,numo)) < 0)  /*prend en compte le nbre de pt de gauss*/
		  ret = -1;
		
		printf("\t- Il y a %d valeurs (%s) sur les faces %d  associs au maillage %s\n",nval,dt_unit,typare[k],maa_ass);
		
		if (nval > 0) {
		  if (typcha == MED_REEL64)  {
		    valr = (med_float*) calloc(ncomp*nval,sizeof(med_int));
		    ret = MEDchampLire(fid,maa,nomcha,(unsigned char*)valr,USER_INTERLACE,MED_ALL,
				       pflname,MED_FACE,typfac[k],numdt,numo);
		    for (l=0;l<nval*ncomp;l++) printf("\t- Valeurs : %f\n",*(valr+l));
		    free(valr);
		  } else {
		    vale = (med_int*) calloc(ncomp*nval,sizeof(med_int));
		    ret = MEDchampLire(fid,maa,nomcha,(unsigned char*)vale,USER_INTERLACE,MED_ALL,
				       pflname,MED_FACE,typfac[k],numdt,numo);
		    for (l=0;l<nval*ncomp;l++)  printf("\t- Valeurs : %i\n",*(vale+l));
		    free(vale);
		  }
		}
		
		if (strcmp(pflname,MED_NOPFL) == 0 )
		  printf("\t- Profil : MED_NOPFL\n");
		else {
		  if ( (pflsize = MEDnValProfil(fid,pflname)) <0) return -1;
		  else {
		    printf("\t- Profil : %s de taille %i\n",pflname,pflsize);
		    pflval = (med_int*) malloc(sizeof(med_int)*pflsize);
		    if ( (ret = MEDprofilLire(fid,pflval, pflname)) <0) return -1;
		    for (l=0;l<pflsize;l++)
		      printf("\t%i\n",*(pflval+l));
		    free(pflval);
		  }
		}
	      }
	    }
	    
            /*  sur les aretes */
            for (k=0;k<MED_NBR_GEOMETRIE_ARETE;k++) {
	      /* Combien de (PDT,NPR) a lire */
	      /* sur les aretes */
	      nbpdtnor = MEDnPasdetemps(fid,nomcha,MED_ARETE,typare[k]);
	      if (nbpdtnor < 1 ) continue;
                  
	      for (j=0;j<nbpdtnor;j++) {
		/* Ajouter les informations sur le profil ?? dans MEDpasdetempsInfo */
		ret = MEDpasdetempsInfo(fid,nomcha,MED_ARETE,typare[k],
					j+1, maa_ass, &ngauss, &numdt,  dt_unit, &dt, &numo);
                    
		printf("\n\tPas de Temps n %4i (%f), Nd'ordre %4i, avec %i pts de gauss\n",numdt,dt,numo,ngauss);
                    
		if ((nval = MEDnVal(fid,nomcha,MED_ARETE,typare[k],numdt,numo)) < 0)  /*prend en compte le nbre de pt de gauss*/
		  ret = -1;
                    
		printf("\t- Il y a %d valeurs (%s) sur les aretes %d  associs au maillage %s\n",nval,dt_unit,typare[k],maa_ass);
                    
		if (nval > 0) {
		  if (typcha == MED_REEL64)
		    {
		      valr = (med_float*) calloc(ncomp*nval,sizeof(med_int));
		      ret = MEDchampLire(fid,maa,nomcha,(unsigned char*)valr,USER_INTERLACE,MED_ALL,
					 pflname,MED_ARETE,typare[k],numdt,numo);
		      for (l=0;l<nval*ncomp;l++)  printf("\t- Valeurs : %f\n",*(valr+l));
		      free(valr);
		    }
		  else {
		    vale = (med_int*) calloc(ncomp*nval,sizeof(med_int));
		    ret = MEDchampLire(fid,maa,nomcha,(unsigned char*)vale,USER_INTERLACE,MED_ALL,
				       pflname,MED_ARETE,typare[k],numdt,numo);
		    for (l=0;l<nval*ncomp;l++) printf("\t- Valeurs : %i\n",*(vale+l));
		    free(vale);
		  }
		}

		if (strcmp(pflname,MED_NOPFL) == 0 )
		  printf("\t- Profil : MED_NOPFL\n");
		else {
		  if ( (pflsize = MEDnValProfil(fid,pflname)) <0) return -1;
		  else {
		    printf("\t- Profil : %s de taille %i\n",pflname,pflsize);
		    pflval = (med_int*) malloc(sizeof(med_int)*pflsize);
		    if ( (ret = MEDprofilLire(fid,pflval,pflname)) <0) return -1;
		    for (l=0;l<pflsize;l++) printf("\t%i\n",*(pflval+l));
		    free(pflval);
		  }
		}
	      }
	    } /*FIN for sur aretes */
	    
	  } /* fin if ret ... */
       
      } /*FIN for i */
  

  /* Interrogation des profils */
  if (ret == 0)
    npro = MEDnProfil(fid);
  
  if (ret >= 0 ) {
    printf("\nNombre de profils stocks : %i\n",ret);
    for (i=1 ; i <= npro ; i++ ) {
      ret = MEDprofilInfo(fid, i, pflname, &nval);
      printf("\t- Profil n%i de nom |%s| et de taille %i\n",i,pflname,nval);
    }
  }
  
  /* fermeture du fichier */
  ret = MEDfermer(fid);
  printf("%d\n",ret);
  
  return 0;
}





  
        
