/*************************************************************************
* COPYRIGHT (C) 1999 - 2002  EDF R&D
* THIS LIBRARY IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
* IT UNDER THE TERMS OF THE GNU LESSER GENERAL PUBLIC LICENSE 
* AS PUBLISHED BY THE FREE SOFTWARE FOUNDATION; 
* EITHER VERSION 2.1 OF THE LICENSE, OR (AT YOUR OPTION) ANY LATER VERSION.
*  
* THIS LIBRARY IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
* WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
* MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
* LESSER GENERAL PUBLIC LICENSE FOR MORE DETAILS.
*
* YOU SHOULD HAVE RECEIVED A COPY OF THE GNU LESSER GENERAL PUBLIC LICENSE
* ALONG WITH THIS LIBRARY; IF NOT, WRITE TO THE FREE SOFTWARE FOUNDATION,
* INC., 59 TEMPLE PLACE, SUITE 330, BOSTON, MA 02111-1307 USA
*
*************************************************************************/

/******************************************************************************
 * - Nom du fichier : test13.c
 *
 * - Description : lecture des equivalences d'un fichier MED 
 *
 *****************************************************************************/

#include <med.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>

/******************************************************************************
 * Description :
 *    - ouverture du fichier
 *    - infos sur le maillage
 *    - lecture des equivalences
 *    - fermeture du fichier
 *****************************************************************************/

#define MED_NBR_MAILLE_EQU 7

int main (int argc, char **argv)
{
  med_err ret;
  med_idt fid;
  char maa[MED_TAILLE_NOM+1];
  med_int mdim;
  med_int nequ,ncor;
  med_int *cor;
  char equ[MED_TAILLE_NOM+1];
  char des[MED_TAILLE_DESC+1];
  med_geometrie_element typmai[MED_NBR_GEOMETRIE_MAILLE] = {MED_POINT1,MED_SEG2, 
						   MED_SEG3,MED_TRIA3,
						   MED_TRIA6,MED_QUAD4,
						   MED_QUAD8,MED_TETRA4,
						   MED_TETRA10,MED_HEXA8,
						   MED_HEXA20,MED_PENTA6,
						   MED_PENTA15,MED_PYRA5,
						   MED_PYRA13};
  med_geometrie_element typfac[MED_NBR_GEOMETRIE_FACE] = {MED_TRIA3,MED_TRIA6,
						 MED_QUAD4,MED_QUAD8};
  med_geometrie_element typare[MED_NBR_GEOMETRIE_ARETE] = {MED_SEG2,MED_SEG3};  
  int i,j,k;

  if (argc != 2)
    return -1;

  /* ouverture du fichier */
  if ((fid = MEDouvrir(argv[1],MED_LECT)) < 0)
    ret = -1;
  else
    ret = 0;
  printf("%d\n",ret);
  
  /* infos sur le premier maillage */
  if (ret == 0)
    ret = MEDmaaInfo(fid,1,maa,&mdim);
  if (ret == 0)
    printf("Maillage de nom %s et de dimension %d \n",maa,mdim);
  printf("%d\n",ret);

  /* combien d'equivalences dans le fichier */
  if (ret == 0)
    if ((nequ = MEDnEquiv(fid,maa)) < 0)
      ret = -1;
  if (ret == 0)
    printf("Nombre d'equivalences : %d \n",nequ);
  printf("%d\n",ret);

  /* lecture de toutes les equivalences associes a maa */
  if (ret == 0)
    for (i = 0;i<nequ;i++)
      {
	printf("Equivalence numero : %d \n",i+1);

	/* lecture des infos sur l'equivalence */
        if (ret == 0)
	  ret = MEDequivInfo(fid,maa,i+1,equ,des);
	printf("%d\n",ret);
        if (ret == 0)
	  {
	    printf("Nom de l'equivalence: %s \n",equ);
            printf("Description de l'equivalence : %s \n",des);
	  }

	/* lecture des correspondances sur les differents types d'entites */
	if (ret == 0)
	  {
	    /* les noeuds */
	    if ((ncor = MEDnCorres(fid,maa,equ,MED_NOEUD,0)) < 0)
	      ret = -1;
	    printf("Il y a %d correspondances sur les noeuds \n",ncor);
	    if (ncor > 0)
	      {
		cor = (med_int*) malloc(sizeof(med_int)*ncor*2);
                ret = MEDequivLire(fid,maa,equ,cor,ncor,MED_NOEUD,0);
                for (j=0;j<ncor;j++)
		  printf("Correspondance %d : %d et %d \n",j+1,*(cor+2*j),
			 *(cor+2*j+1));
                free(cor);
	      }
	    
	    /* sur les mailles : on ne prend pas en compte les mailles 3D */
	    for (j=0;j<MED_NBR_MAILLE_EQU;j++)
	      {
		if ((ncor = MEDnCorres(fid,maa,equ,MED_MAILLE,typmai[j])) < 0)
		  ret = -1;
		printf("Il y a %d correspondances sur les mailles %d \n",ncor,
		       typmai[j]);
		if (ncor > 0)
		  {
		    cor = (med_int*) malloc(sizeof(med_int)*ncor*2);
		    ret = MEDequivLire(fid,maa,equ,cor,ncor,MED_MAILLE,
				       typmai[j]);
		    for (k=0;k<ncor;k++)
		      printf("Correspondance %d : %d et %d \n",k+1,*(cor+2*k),
			     *(cor+2*k+1));
		    free(cor);
		  }
	      }

	    /* sur les faces */
	    for (j=0;j<MED_NBR_GEOMETRIE_FACE;j++)
	      {
		if ((ncor = MEDnCorres(fid,maa,equ,MED_FACE,typfac[j])) < 0)
		  ret = -1;
		printf("Il y a %d correspondances sur les faces %d \n",ncor,
		       typfac[j]);
		if (ncor > 0)
		  {
		    cor = (med_int*) malloc(sizeof(med_int)*ncor*2);
		    ret = MEDequivLire(fid,maa,equ,cor,ncor,MED_FACE,
				       typfac[j]);
		    for (k=0;k<ncor;k++)
		      printf("Correspondance %d : %d et %d \n",k+1,*(cor+2*k),
			     *(cor+2*k+1));
		    free(cor);
		  }
	      }

	    /*  sur les aretes */
	    for (j=0;j<MED_NBR_GEOMETRIE_ARETE;j++)
	      {
		if ((ncor = MEDnCorres(fid,maa,equ,MED_ARETE,typare[j])) < 0)
		  ret = -1;
		printf("Il y a %d correspondances sur les aretes %d \n",ncor,
		       typare[j]);
		if (ncor > 0)
		  {
		    cor = (med_int*) malloc(sizeof(med_int)*ncor*2);
		    ret = MEDequivLire(fid,maa,equ,cor,ncor,MED_ARETE,
				       typare[j]);
		    for (k=0;k<ncor;k++)
		      printf("Correspondance %d : %d et %d \n",k+1,*(cor+2*k),
			     *(cor+2*k+1));
		    free(cor);
		  }
	      }
	  }			    
      }

  /* fermeture du fichier */
  ret = MEDfermer(fid);
  printf("%d\n",ret);

  return 0;
}




