/*************************************************************************
* COPYRIGHT (C) 1999 - 2002  EDF R&D
* THIS LIBRARY IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
* IT UNDER THE TERMS OF THE GNU LESSER GENERAL PUBLIC LICENSE 
* AS PUBLISHED BY THE FREE SOFTWARE FOUNDATION; 
* EITHER VERSION 2.1 OF THE LICENSE, OR (AT YOUR OPTION) ANY LATER VERSION.
*  
* THIS LIBRARY IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
* WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
* MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
* LESSER GENERAL PUBLIC LICENSE FOR MORE DETAILS.
*
* YOU SHOULD HAVE RECEIVED A COPY OF THE GNU LESSER GENERAL PUBLIC LICENSE
* ALONG WITH THIS LIBRARY; IF NOT, WRITE TO THE FREE SOFTWARE FOUNDATION,
* INC., 59 TEMPLE PLACE, SUITE 330, BOSTON, MA 02111-1307 USA
*
*************************************************************************/

/******************************************************************************
 * - Nom du fichier : test2.c
 *
 * - Description : tests de la routine de creation de maillage 
 *                 MED 
 *
 *****************************************************************************/

#include <med.h>
#include <string.h>

/******************************************************************************
 * OUVERTURE/FERMETURE DE FICHIERS :
 *
 * Description :
 *    - ouverture du fichier en mode ecriture avec remplacement
 *    - Affichage d'informations concernant le fichier test1.med (optionnel)
 *    - creation de 3 maillages
 *    - fermeture du fichier
 *****************************************************************************/

int main (int argc, char **argv)
{
  med_err ret=0;
  med_idt fid;
  char    des[MED_TAILLE_DESC+1]="";

  /* Verification de la conformit du format med du fichier test1.med */
  ret = MEDformatConforme("test1.med");
  printf("%d\n",ret);

  /* Ouverture en mode de lecture du fichier test1.med*/
  if (ret == 0) {
    fid = MEDouvrir("test1.med",MED_LECT);
    if (fid < 0)
      ret = -1;
    else
      ret = 0;
    printf("%d\n",ret);
  }

  /* Affiche le n de version d'HDF  */
  if (ret == 0)
    ret = MEDfichEntete(fid, MED_HDF_VERSION, des); 
  if (ret == 0) printf("VERSION DE HDF : %s\n",des);
  printf("%d\n",ret);
  
  /* Affiche le n de version de MED  */
  if (ret == 0)
    ret = MEDfichEntete(fid, MED_VERSION, des);
  if (ret == 0) printf("VERSION DE MED : %s\n",des);
  printf("%d\n",ret);
  
  /*Affiche le descripteur de fichier */
  if (ret == 0)
    ret = MEDfichEntete(fid,MED_FICH_DES, des); 
  if (ret == 0) printf("DESCRIPTEUR DE FICHIER : %s\n",des);
  printf("%d\n",ret);
  
  /* Fermeture du fichier test1.med */
  if (ret == 0)
    ret = MEDfermer(fid); 
  printf("%d\n",ret);
  

  /* Ouverture en mode de remplacement du fichier test2.med*/
  fid = MEDouvrir("test2.med",MED_REMP);
  if (fid < 0)
    ret = -1;
  else
    ret = 0;
  printf("%d\n",ret);
  

  /* creations des maillages maa1,maa2,maa3 de dimensions 3,2,1 */
  if (ret == 0)
    ret = MEDmaaCr(fid,"maa1",3);
  printf("%d\n",ret);

  if (ret == 0)
    ret = MEDunvCr(fid,"maa1");
  printf("%d\n",ret);

  if (ret == 0)
    ret = MEDmaaCr(fid,"maa2",2);
  printf("%d\n",ret);

  if (ret == 0)
    ret = MEDunvCr(fid,"maa2");
  printf("%d\n",ret);

  if (ret == 0)
    ret = MEDmaaCr(fid,"maa3",1);
  printf("%d\n",ret);

  if (ret == 0)
    ret = MEDunvCr(fid,"maa3");
  printf("%d\n",ret);
 

  ret = MEDfermer(fid);
  printf("%d\n",ret);
  
  return 0;
}




