/*************************************************************************
* COPYRIGHT (C) 1999 - 2002  EDF R&D
* THIS LIBRARY IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
* IT UNDER THE TERMS OF THE GNU LESSER GENERAL PUBLIC LICENSE 
* AS PUBLISHED BY THE FREE SOFTWARE FOUNDATION; 
* EITHER VERSION 2.1 OF THE LICENSE, OR (AT YOUR OPTION) ANY LATER VERSION.
*  
* THIS LIBRARY IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
* WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
* MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
* LESSER GENERAL PUBLIC LICENSE FOR MORE DETAILS.
*
* YOU SHOULD HAVE RECEIVED A COPY OF THE GNU LESSER GENERAL PUBLIC LICENSE
* ALONG WITH THIS LIBRARY; IF NOT, WRITE TO THE FREE SOFTWARE FOUNDATION,
* INC., 59 TEMPLE PLACE, SUITE 330, BOSTON, MA 02111-1307 USA
*
*************************************************************************/


/******************************************************************************
 * - Nom du fichier : test6.c
 *
 * - Description : ecriture d'elements de maillages MED
 *                 via les routines de bas niveau
 *
 *****************************************************************************/

#include <med.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>

/******************************************************************************
 * Description :
 *    - ouverture du fichier
 *    - ecriture des elements (mailles,faces,aretes) : connectivite,
 *      noms,numeros,numeros de familles
 *    - fermeture du fichier
 *****************************************************************************/

int main (int argc, char **argv)
{
  med_err ret;
  med_idt fid;
  med_int nse2 = 5;
  med_int se2[10] = {1,2,1,3,2,4,3,4,2,3};
  char nomse2[MED_TAILLE_PNOM*5+1]="se1     se2     se3     se4     se5     ";
  med_int numse2[5] = {1,2,3,4,5};
  med_int nufase2[5] = {-1,-1,0,-2,-3}; 
  med_int ntr3 = 2;
  med_int tr3[6] = {1,2,-5,-5,3,-4};
  char nomtr3[MED_TAILLE_PNOM*2+1] = "tr1     tr2     ";
  med_int numtr3[2] = {4,5};
  med_int nufatr3[2] = {0,-1};
  char maa[MED_TAILLE_NOM+1] = "maa1";
  med_int mdim = 2;

  /* ouverture du fichier */
  fid = MEDouvrir("test6.med",MED_REMP);
  if (fid == -1)
    ret = fid;
  else
    ret = 0;
  printf("%d\n",ret);

  /* creation du maillage */
  if (ret == 0)
    ret = MEDmaaCr(fid,maa,mdim);
  printf("%d\n",ret);
  /* ecriture des connectivites des segments */
  if (ret == 0)
    ret = MEDconnEcr(fid,maa,mdim,se2,MED_FULL_INTERLACE,nse2,MED_ECRI,MED_ARETE,MED_SEG2,
		     MED_DESC);
  printf("%d\n",ret);

  /* ecriture (optionnelle) des noms des segments */
  if (ret == 0)
    ret = MEDnomEcr(fid,maa,nomse2,nse2,MED_ECRI,MED_ARETE,MED_SEG2);
  printf("%d\n",ret);

  /* ecriture (optionnelle) des numeros des segments */
  if (ret == 0)
    ret = MEDnumEcr(fid,maa,numse2,nse2,MED_ECRI,MED_ARETE,MED_SEG2);
  printf("%d\n",ret);

  /* ecriture des numeros des familles des segments */
  if (ret == 0)
    ret = MEDfamEcr(fid,maa,nufase2,nse2,MED_ECRI,MED_ARETE,MED_SEG2);
  printf("%d\n",ret);

  /* ecriture des connectivites des triangles */
  if (ret == 0)
    ret = MEDconnEcr(fid,maa,mdim,tr3,MED_FULL_INTERLACE,ntr3,MED_ECRI,MED_MAILLE,MED_TRIA3,
		     MED_DESC);
  printf("%d\n",ret);

  /* ecriture (optionnelle) des noms des triangles */
  if (ret == 0)
    ret = MEDnomEcr(fid,maa,nomtr3,ntr3,MED_ECRI,MED_MAILLE,MED_TRIA3);
  printf("%d\n",ret);

  /* ecriture (optionnelle) des numeros des triangles */
  if (ret == 0)
    ret = MEDnumEcr(fid,maa,numtr3,ntr3,MED_ECRI,MED_MAILLE,MED_TRIA3);
  printf("%d\n",ret);

  /* ecriture des numeros des familles des triangles */
  if (ret == 0)
    ret = MEDfamEcr(fid,maa,nufatr3,ntr3,MED_ECRI,MED_MAILLE,MED_TRIA3);
  printf("%d\n",ret);

  /* fermeture du fichier */
  ret = MEDfermer(fid);
  printf("%d\n",ret);
}




