/*************************************************************************
* COPYRIGHT (C) 1999 - 2002  EDF R&D
* THIS LIBRARY IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
* IT UNDER THE TERMS OF THE GNU LESSER GENERAL PUBLIC LICENSE 
* AS PUBLISHED BY THE FREE SOFTWARE FOUNDATION; 
* EITHER VERSION 2.1 OF THE LICENSE, OR (AT YOUR OPTION) ANY LATER VERSION.
*  
* THIS LIBRARY IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
* WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
* MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
* LESSER GENERAL PUBLIC LICENSE FOR MORE DETAILS.
*
* YOU SHOULD HAVE RECEIVED A COPY OF THE GNU LESSER GENERAL PUBLIC LICENSE
* ALONG WITH THIS LIBRARY; IF NOT, WRITE TO THE FREE SOFTWARE FOUNDATION,
* INC., 59 TEMPLE PLACE, SUITE 330, BOSTON, MA 02111-1307 USA
*
*************************************************************************/

/******************************************************************************
 * - Nom du fichier : test7.c
 *
 * - Description : lecture d'elements de maillages MED ecrits par test6
 *                 via les routines de bas niveau
 *
 *****************************************************************************/

#include <med.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>

/******************************************************************************
 * Description :
 *    - ouverture du fichier
 *    - lecture d'elements (mailles,faces,aretes) : connectivite,
 *      noms,numeros,numeros de familles
 *    - fermeture du fichier
 *****************************************************************************/

int main (int argc, char **argv)
{
  med_err ret;
  med_idt fid;
  med_int nse2;
  med_int *se2_1;
  med_int *se2_2;
  char *nomse2;
  med_int *numse2;
  med_int *nufase2; 
  med_int ntr3;
  med_int *tr3;
  char *nomtr3;
  med_int *numtr3;
  med_int *nufatr3;
  char maa[MED_TAILLE_NOM+1] ="maa1";
  med_int mdim = 2;
  med_booleen inoele,inuele;
  med_int tse2,ttr3;
  med_int i;
  char str[MED_TAILLE_PNOM+1];
  med_int profil[2] = { 2, 3 };
  
  /* ouverture du fichier */
  if ((fid = MEDouvrir("test6.med",MED_LECT)) < 0)
    ret = -1;
  else
    ret = 0;
  printf("%d\n",ret);

  if (ret == 0)
    {
      ret = MEDmaaInfo(fid,1,maa,&mdim);
      printf("Maillage de nom : %s et de dimension %d \n",maa,mdim);
    }
  printf("%d\n",ret);

  /* combien de triangles et de segments */
  if (ret == 0)
    if ((nse2 = MEDnEntMaa(fid,maa,MED_CONN,MED_ARETE,MED_SEG2,MED_DESC)) < 0)
      ret = -1;
  printf("%d\n",nse2);
  if (ret == 0)
    if ((ntr3 = MEDnEntMaa(fid,maa,MED_CONN,MED_MAILLE,MED_TRIA3,MED_DESC))<0)
      ret = -1;
  printf("%d\n",ret);
  if (ret == 0)
    printf("Nombre de MED_SEG2 : %d - nombre de MED_TRIA3 : %d\n",nse2,ntr3);

  /* allocations memoire */ 
  tse2 = 2;
  se2_1  = (med_int*) calloc(tse2*nse2,sizeof(med_int));
  se2_2  = (med_int*) malloc(sizeof(med_int)*tse2*nse2);
  nomse2 = (char*) malloc(MED_TAILLE_PNOM*nse2+1);
  numse2 = (med_int*) malloc(sizeof(med_int)*nse2);
  nufase2 = (med_int*) malloc(sizeof(med_int)*nse2);

  ttr3 = 3;
  tr3 = (med_int*) malloc(sizeof(med_int)*ntr3*ttr3);
  nomtr3 = (char*) malloc(MED_TAILLE_PNOM*ntr3+1);
  numtr3 = (med_int*) malloc(sizeof(med_int)*ntr3);
  nufatr3 = (med_int*) malloc(sizeof(med_int)*ntr3);

  /* lecture des connectivites des segments avec profil */
  if (ret == 0)
    ret = MEDconnLire(fid,maa,mdim,se2_1,MED_FULL_INTERLACE,profil,2,MED_ARETE,MED_SEG2,MED_DESC);
  printf("%d\n",ret);

  /* lecture des connectivites des segments */
  if (ret == 0)
    ret = MEDconnLire(fid,maa,mdim,se2_2,MED_FULL_INTERLACE,NULL,0,MED_ARETE  ,MED_SEG2,MED_DESC);
  printf("%d\n",ret);

  /* lecture (optionnelle) des noms des segments */
  if (ret == 0)
    if (MEDnomLire(fid,maa,nomse2,nse2,MED_ARETE,MED_SEG2) < 0)
      inoele = MED_FAUX;
    else
      inoele = MED_VRAI;

  /* lecture (optionnelle) des numeros des segments */
  if (ret == 0)
    if (MEDnumLire(fid,maa,numse2,nse2,MED_ARETE,MED_SEG2) < 0)
      inuele = MED_FAUX;
    else
      inuele = MED_VRAI;

  /* lecture des numeros des familles des segments */
  if (ret == 0)
    ret = MEDfamLire(fid,maa,nufase2,nse2,MED_ARETE,MED_SEG2);
  printf("%d\n",ret);

  /* lecture des connectivites des triangles */
  if (ret == 0)
    ret = MEDconnLire(fid,maa,mdim,tr3,MED_NO_INTERLACE,NULL,0,MED_MAILLE,MED_TRIA3,
		     MED_DESC);
  printf("%d\n",ret);

  /* lecture (optionnelle) des noms des triangles */
  if (ret == 0)
    if (MEDnomLire(fid,maa,nomtr3,ntr3,MED_MAILLE,MED_TRIA3) < 0)
      inoele = MED_FAUX;
    else
      inoele = MED_VRAI;
  printf("%d\n",ret);

  /* lecture (optionnelle) des numeros des triangles */
  if (ret == 0)
    if (MEDnumLire(fid,maa,numtr3,ntr3,MED_MAILLE,MED_TRIA3) < 0)
      inuele = MED_FAUX;
    else
      inuele = MED_VRAI;
  printf("%d\n",ret);

  /* lecture des numeros des familles des triangles */
  if (ret == 0)
    ret = MEDfamLire(fid,maa,nufatr3,ntr3,MED_MAILLE,MED_TRIA3);
  printf("%d\n",ret);

  /* fermeture du fichier */
  ret = MEDfermer(fid);
  printf("%d\n",ret);

  /* affichage */
  if (ret == 0)
    {
      printf("Connectivite des segments (1): \n");
      for (i=0;i<nse2*tse2;i++)
	printf("%d ",*(se2_1+i));
      printf("\n");
      printf("Connectivite des segments (2): \n");
      for (i=0;i<nse2*tse2;i++)
	printf("%d ",*(se2_2+i));
      if (inoele)
	{
	  printf("\nNoms des segments :\n");
          for (i=0;i<nse2;i++)
	    {
	      strncpy(str,nomse2+i*MED_TAILLE_PNOM,MED_TAILLE_PNOM);
	      str[MED_TAILLE_PNOM] = '\0';
	      printf("%s ",str);
	    }
	}
      if (inuele)
	{
	  printf("\nNumeros des segments :\n");
          for (i=0;i<nse2;i++)
	    printf("%d ",*(numse2+i));
	}      
      printf("\nNumeros des familles des segments :\n");
      for (i=0;i<nse2;i++)
	    printf("%d ",*(nufase2+i));

      printf("\nConnectivite des triangles : \n");
      for (i=0;i<ntr3*ttr3;i++)
	printf("%d ",*(tr3+i));
      if (inoele)
	{
	  printf("\nNoms des triangles :\n");
          for (i=0;i<ntr3;i++)
	    {
	      strncpy(str,nomtr3+i*MED_TAILLE_PNOM,MED_TAILLE_PNOM);
	      str[MED_TAILLE_PNOM] = '\0';
	      printf("%s ",str);
	    }
	}
      if (inuele)
	{
	  printf("\nNumeros des triangles :\n");
          for (i=0;i<ntr3;i++)
	    printf("%d ",*(numtr3+i));
	}      
      printf("\nNumeros des familles des triangles :\n");
      for (i=0;i<ntr3;i++)
	    printf("%d ",*(nufatr3+i));

      printf("\n");
    }

  /* nettoyage memoire */
  free(se2_1);
  free(se2_2);
  free(nomse2);
  free(numse2);
  free(nufase2);

  free(tr3);
  free(nomtr3);
  free(numtr3);
  free(nufatr3);

  return 0;
}




