/*************************************************************************
* COPYRIGHT (C) 1999 - 2002  EDF R&D
* THIS LIBRARY IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
* IT UNDER THE TERMS OF THE GNU LESSER GENERAL PUBLIC LICENSE 
* AS PUBLISHED BY THE FREE SOFTWARE FOUNDATION; 
* EITHER VERSION 2.1 OF THE LICENSE, OR (AT YOUR OPTION) ANY LATER VERSION.
*  
* THIS LIBRARY IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
* WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
* MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
* LESSER GENERAL PUBLIC LICENSE FOR MORE DETAILS.
*
* YOU SHOULD HAVE RECEIVED A COPY OF THE GNU LESSER GENERAL PUBLIC LICENSE
* ALONG WITH THIS LIBRARY; IF NOT, WRITE TO THE FREE SOFTWARE FOUNDATION,
* INC., 59 TEMPLE PLACE, SUITE 330, BOSTON, MA 02111-1307 USA
*
*************************************************************************/


/******************************************************************************
 * - Nom du fichier : test9.c
 *
 * - Description : lecture des familles d'un maillage MED 
 *                 via les routines de bas niveau
 *
 *****************************************************************************/

#include <med.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>

/******************************************************************************
 * Description :
 *    - ouverture du fichier
 *    - lecture des familles
 *    - fermeture du fichier
 *****************************************************************************/

int main (int argc, char **argv)
{
  med_err ret;
  med_idt fid;
  char maa[MED_TAILLE_NOM+1];
  med_int mdim;
  med_int nfam;
  med_int i,j;
  med_int natt,ngro;
  char *attdes,*gro;
  med_int *attval,*attide;
  char nomfam[MED_TAILLE_NOM+1];
  med_int numfam;
  char str1[MED_TAILLE_DESC+1];
  char str2[MED_TAILLE_LNOM+1];

  /* ouverture du fichier */
  if ((fid = MEDouvrir("test8.med",MED_LECT)) < 0)
    ret = -1;
  else
    ret = 0;
  printf("%d\n",ret);

  /* info sur le maillage */
  if (ret == 0)
    ret = MEDmaaInfo(fid,1,maa,&mdim);
  printf("%d\n",ret);

  /* nombre de familles */
  if (ret == 0)
    {
      if ((nfam = MEDnFam(fid,maa,0,0)) < 0)
	ret = -1;
      printf("Nombre de familles : %d \n",nfam);
    }
  printf("%d\n",ret);

  /* lecture de chaque famille */
  if (ret == 0)
    for (i=0;i<nfam;i++)
      {
	
	/* nombre de groupes */
	if (ret == 0)
	  if ((ngro = MEDnFam(fid,maa,i+1,MED_GROUPE)) < 0)
	    ret = -1;
	printf("%d\n",ret);
	
	/* nombre d'attributs */
	if (ret == 0)
	  if ((natt = MEDnFam(fid,maa,i+1,MED_ATTR)) < 0)
	    ret = -1;
	printf("%d\n",ret);

	printf("Famille %d a %d attributs et %d groupes \n",i+1,natt,ngro); 

	/* nom,numero,attributs,groupes */
	if (ret == 0)
	  {
	    attide = (med_int*) malloc(sizeof(med_int)*natt);
	    attval = (med_int*) malloc(sizeof(med_int)*natt);	    
	    attdes = (char *) malloc(MED_TAILLE_DESC*natt+1);
	    gro = (char*) malloc(MED_TAILLE_LNOM*ngro+1);
	    ret = MEDfamInfo(fid,maa,i+1,nomfam,&numfam,attide,attval,attdes,
			     &natt,gro,&ngro);
            printf("%d\n",ret);
	    printf("Famille de nom %s et de numero %d : \n",nomfam,numfam);
	    printf("Attributs : \n");
	    for (j=0;j<natt;j++)
	      {
		strncpy(str1,attdes+j*MED_TAILLE_DESC,MED_TAILLE_DESC);
		str1[MED_TAILLE_DESC] = '\0';
		printf("ide = %d - val = %d - des = %s\n",*(attide+j),
		       *(attval+j),str1);
	      }
            free(attide);
	    free(attval);
            free(attdes);	
	    for (j=0;j<ngro;j++)
	      {
		strncpy(str2,gro+j*MED_TAILLE_LNOM,MED_TAILLE_LNOM);
		str2[MED_TAILLE_LNOM] = '\0';
		printf("gro = %s\n",str2);
	      }
            free(gro);
	  }
      }


  /* fermeture du fichier */
  ret = MEDfermer(fid);
  printf("%d\n",ret);

  return 0;
}




